import { MiniProgram } from "..";
import { IAddOrderParams, IGetOrderParams, IGetPathParams, IOrder, IPathItemList } from "./interface";
/**
 * 物流助手
 * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.addOrder.html
 */
export declare class Logistics {
    private mini;
    constructor(mini: MiniProgram);
    /**
     * 生成运单
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.addOrder.html
     */
    addOrder(body: IAddOrderParams): Promise<import("../../interface").IError & import("./interface").IExpressOrder>;
    /**
     * 批量获取运单数据
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.batchGetOrder.html
     */
    batchGetOrder(body: {
        order_list: Array<IOrder>;
    }): Promise<import("../../interface").IError & {
        order_list: (import("../../interface").IError & IOrder)[];
    }>;
    /**
     * 绑定、解绑物流账号
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.bindAccount.html
     */
    bindAccount(body: {
        type: string;
        biz_id: string;
        delivery_id: string;
        password: string;
        remark_content: string;
    }): Promise<import("../../interface").IError>;
    /**
     * 取消运单
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.cancelOrder.html
     */
    cancelOrder(body: {
        order_id: string;
        openid?: string;
        delivery_id: string;
        waybill_id: string;
    }): Promise<import("../../interface").IError>;
    /**
     * 获取所有绑定的物流账号
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.getAllAccount.html
     */
    getAllAccount(): Promise<import("../../interface").IError & {
        count: number;
        list: {
            biz_id: string;
            delivery_id: string;
            create_time: number;
            update_time: number;
            status_code: number;
            alias: string;
            remark_wrong_msg: string;
            remark_content: string;
            quota_num: number;
            quota_update_time: number;
            service_type: import("./interface").IService[];
        }[];
    }>;
    /**
     * 获取支持的快递公司列表
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.getAllAccount.html
     */
    getAllDelivery(): Promise<import("../../interface").IError & {
        count: number;
        data: {
            delivery_id: string; /**
             * 获取运单数据
             * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.getOrder.html
             */
            delivery_name: string;
            can_use_cash: number;
            can_get_quota: number;
            cash_biz_id: string;
            service_type: import("./interface").IService[];
        }[];
    }>;
    /**
     * 获取运单数据
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.getOrder.html
     */
    getOrder(body: IGetOrderParams): Promise<import("../../interface").IError & IOrder>;
    /**
     * 查询运单轨迹
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.getPath.html
     */
    getPath(body: IGetPathParams): Promise<import("../../interface").IError & {
        openid: string;
        delivery_id: string;
        waybill_id: string;
        path_item_num: number;
        path_item_list: IPathItemList[];
    }>;
    /**
     * 获取打印员
     * 若需要使用微信打单 PC 软件，才需要调用。
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.getPrinter.html
     */
    getPrinter(): Promise<import("../../interface").IError & {
        count: number;
        openid: string[];
        tagid_list: string[];
    }>;
    /**
     * 获取电子面单余额
     * 仅在使用加盟类快递公司时，才可以调用。
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.getQuota.html
     */
    getQuota(body: {
        delivery_id: string;
        biz_id: string;
    }): Promise<import("../../interface").IError & {
        quota_num: number;
    }>;
    /**
     * 模拟快递公司更新订单状态
     * 该接口只能用户测试
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.testUpdateOrder.html
     */
    testUpdateOrder(body: {
        delivery_id: string;
        biz_id: string;
        order_id: string;
        waybill_id: string;
    } & IPathItemList): Promise<import("../../interface").IError>;
    /**
     * 配置面单打印员
     * 可以设置多个，若需要使用微信打单 PC 软件，才需要调用
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.testUpdateOrder.html
     */
    updatePrinter(body: {
        openid: string;
        update_type: "bind" | "unbind";
        tagid_list?: string;
    }): Promise<import("../../interface").IError>;
}
