"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logistics = void 0;
/**
 * 物流助手
 * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.addOrder.html
 */
class Logistics {
    constructor(mini) {
        this.mini = mini;
    }
    /**
     * 生成运单
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.addOrder.html
     */
    addOrder(body) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/express/business/order/add";
            const resp = yield this.mini.http.post(url, body);
            if (resp.data.errcode) {
                throw new Error(`生成运单失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
    /**
     * 批量获取运单数据
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.batchGetOrder.html
     */
    batchGetOrder(body) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/express/business/order/add";
            const resp = yield this.mini.http.post(url, body);
            if (resp.data.errcode) {
                throw new Error(`批量获取运单数据失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
    /**
     * 绑定、解绑物流账号
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.bindAccount.html
     */
    bindAccount(body) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/express/business/account/bind";
            const resp = yield this.mini.http.post(url, body);
            if (resp.data.errcode) {
                throw new Error(`绑定、解绑物流账号失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
    /**
     * 取消运单
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.cancelOrder.html
     */
    cancelOrder(body) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/express/business/order/cancel";
            const resp = yield this.mini.http.post(url, body);
            if (resp.data.errcode) {
                throw new Error(`取消运单失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
    /**
     * 获取所有绑定的物流账号
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.getAllAccount.html
     */
    getAllAccount() {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/express/business/account/getall";
            const resp = yield this.mini.http.get(url);
            if (resp.data.errcode) {
                throw new Error(`获取所有绑定的物流账号失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
    /**
     * 获取支持的快递公司列表
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.getAllAccount.html
     */
    getAllDelivery() {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/express/business/delivery/getall";
            const resp = yield this.mini.http.get(url);
            if (resp.data.errcode) {
                throw new Error(`获取支持的快递公司列表失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
    /**
     * 获取运单数据
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.getOrder.html
     */
    getOrder(body) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/express/business/order/get";
            const resp = yield this.mini.http.post(url, body);
            if (resp.data.errcode) {
                throw new Error(`获取运单数据失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
    /**
     * 查询运单轨迹
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.getPath.html
     */
    getPath(body) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/express/business/path/get";
            const resp = yield this.mini.http.post(url, body);
            if (resp.data.errcode) {
                throw new Error(`查询运单轨迹失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
    /**
     * 获取打印员
     * 若需要使用微信打单 PC 软件，才需要调用。
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.getPrinter.html
     */
    getPrinter() {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/express/business/printer/getall";
            const resp = yield this.mini.http.get(url);
            if (resp.data.errcode) {
                throw new Error(`获取打印员失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
    /**
     * 获取电子面单余额
     * 仅在使用加盟类快递公司时，才可以调用。
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.getQuota.html
     */
    getQuota(body) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/express/business/quota/get";
            const resp = yield this.mini.http.post(url, body);
            if (resp.data.errcode) {
                throw new Error(`获取电子面单余额失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
    /**
     * 模拟快递公司更新订单状态
     * 该接口只能用户测试
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.testUpdateOrder.html
     */
    testUpdateOrder(body) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/express/business/test_update_order";
            const resp = yield this.mini.http.post(url, body);
            if (resp.data.errcode) {
                throw new Error(`模拟快递公司更新订单状态失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
    /**
     * 配置面单打印员
     * 可以设置多个，若需要使用微信打单 PC 软件，才需要调用
     * https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/express/by-business/logistics.testUpdateOrder.html
     */
    updatePrinter(body) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/express/business/test_update_order";
            const resp = yield this.mini.http.post(url, body);
            if (resp.data.errcode) {
                throw new Error(`配置面单打印员失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
}
exports.Logistics = Logistics;
