/// <reference types="node" />
import { OfficialAccount } from "..";
import { IMPCustomerServiceList, IMPCustomerServiceMessage } from "./interface";
/**
 * 客服消息接口
 * https://developers.weixin.qq.com/doc/offiaccount/Message_Management/Service_Center_messages.html
 */
export declare class CustomerService {
    private oa;
    constructor(oa: OfficialAccount);
    /**
     * 获取所有客服账号
     */
    list(): Promise<IMPCustomerServiceList>;
    /**
     * 获取所有在线客服账号
     */
    online(): Promise<IMPCustomerServiceList>;
    /**
     * 创建客服账号
     */
    create(account: string, nickname: string, password?: string): Promise<string>;
    /**
     * 更新客服账号
     */
    update(account: string, nickname: string, password?: string): Promise<string>;
    /**
     * 更新客服账号
     */
    delete(account: string, nickname: string, password?: string): Promise<string>;
    /**
     * 更新客服账号
     */
    setAvatar(account: string, jpeg: Buffer): Promise<string>;
    /**
     * 发送客服消息
     */
    send(msg: IMPCustomerServiceMessage): Promise<string>;
    /**
     * 下发客服正在输入状态
     */
    showTypingStatusToUser(openid: string): Promise<string>;
    /**
     * 隐藏客服正在输入状态
     */
    hideTypingStatusToUser(openid: string): Promise<string>;
    /**
     * 获取历史客服消息
     */
    messages(startTime: number, endTime: number, msgId?: number, number?: number): Promise<string>;
}
