"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomerService = void 0;
const FormData = require("form-data");
/**
 * 客服消息接口
 * https://developers.weixin.qq.com/doc/offiaccount/Message_Management/Service_Center_messages.html
 */
class CustomerService {
    constructor(oa) {
        this.oa = oa;
    }
    /**
     * 获取所有客服账号
     */
    list() {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/customservice/getkflist";
            const resp = yield this.oa.http.get(url);
            if (resp.data.errcode) {
                throw new Error(`获取所有客服账号失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data.kf_list;
        });
    }
    /**
     * 获取所有在线客服账号
     */
    online() {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/customservice/getonlinekflist";
            const resp = yield this.oa.http.get(url);
            if (resp.data.errcode) {
                throw new Error(`获取所有在线客服账号失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data.kf_list;
        });
    }
    /**
     * 创建客服账号
     */
    create(account, nickname, password) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "customservice/kfaccount/add";
            const body = {
                kf_account: account,
                nickname,
                password
            };
            const resp = yield this.oa.http.post(url, body);
            if (resp.data.errcode) {
                throw new Error(`创建客服账号失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data.errmsg;
        });
    }
    /**
     * 更新客服账号
     */
    update(account, nickname, password) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "customservice/kfaccount/update";
            const body = {
                kf_account: account,
                nickname,
                password
            };
            const resp = yield this.oa.http.post(url, body);
            if (resp.data.errcode) {
                throw new Error(`更新客服账号失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data.errmsg;
        });
    }
    /**
     * 更新客服账号
     */
    delete(account, nickname, password) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "customservice/kfaccount/del";
            const body = {
                kf_account: account,
                nickname,
                password
            };
            const resp = yield this.oa.http.post(url, body);
            if (resp.data.errcode) {
                throw new Error(`更新客服账号失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data.errmsg;
        });
    }
    /**
     * 更新客服账号
     */
    setAvatar(account, jpeg) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "customservice/kfaccount/uploadheadimg";
            const params = {
                kf_account: account
            };
            const form = new FormData();
            form.append("file", jpeg, "avatar.jpg");
            const resp = yield this.oa.http.post(url, form, {
                params,
                headers: form.getHeaders()
            });
            if (resp.data.errcode) {
                throw new Error(`更新客服账号失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data.errmsg;
        });
    }
    /**
     * 发送客服消息
     */
    send(msg) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/message/custom/send";
            const resp = yield this.oa.http.post(url, msg);
            if (resp.data.errcode) {
                throw new Error(`发送客服消息失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data.errmsg;
        });
    }
    /**
     * 下发客服正在输入状态
     */
    showTypingStatusToUser(openid) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/message/custom/send";
            const body = {
                touser: openid,
                command: "Typing"
            };
            const resp = yield this.oa.http.post(url, body);
            if (resp.data.errcode) {
                throw new Error(`下发客服正在输入状态失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data.errmsg;
        });
    }
    /**
     * 隐藏客服正在输入状态
     */
    hideTypingStatusToUser(openid) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/message/custom/send";
            const body = {
                touser: openid,
                command: "CancelTyping"
            };
            const resp = yield this.oa.http.post(url, body);
            if (resp.data.errcode) {
                throw new Error(`下发客服正在输入状态失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data.errmsg;
        });
    }
    /**
     * 获取历史客服消息
     */
    messages(startTime, endTime, msgId = 1, number = 10000) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "cgi-bin/message/custom/send";
            const body = {
                starttime: startTime,
                endtime: endTime,
                msgid: msgId,
                number
            };
            const resp = yield this.oa.http.post(url, body);
            if (resp.data.errcode) {
                throw new Error(`获取历史客服消息失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data.errmsg;
        });
    }
}
exports.CustomerService = CustomerService;
