"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MPOAuth = void 0;
const querystring = require("querystring");
/**
 * 微信网页授权
 * https://developers.weixin.qq.com/doc/offiaccount/OA_Web_Apps/Wechat_webpage_authorization.html
 */
class MPOAuth {
    constructor(oa) {
        this.oa = oa;
    }
    /**
     * 跳转微信授权
     * https://developers.weixin.qq.com/doc/offiaccount/OA_Web_Apps/Wechat_webpage_authorization.html
     */
    redirect(redirect_uri, scope) {
        return (req, res) => {
            const { state = "STATE" } = req.query;
            const queryStr = querystring.stringify({
                appid: this.oa.config.appId,
                redirect_uri: "http://" + req.hostname + redirect_uri,
                response_type: "code",
                scope,
                state
            });
            const authUrl = `https://open.weixin.qq.com/connect/oauth2/authorize?${queryStr}#wechat_redirect`;
            res.redirect(authUrl);
        };
    }
    /**
     * 通过 Code 换取 OpenId
     * @param code
     */
    getUserAccessToken(code) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "sns/oauth2/access_token";
            const params = {
                appid: this.oa.config.appId,
                secret: this.oa.config.secret,
                code,
                grant_type: "authorization_code"
            };
            const resp = yield this.oa.http.get(url, { params });
            if (resp.data.errcode) {
                throw new Error(`通过 Code 换取 OpenId 失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
    /**
     * 通过 access_token 换取 userinfo
     * @param access_token
     * @param openid
     * @param lang
     */
    getUserInfo(access_token, openid, lang = "zh_CN") {
        return __awaiter(this, void 0, void 0, function* () {
            const url = "sns/userinfo";
            const params = {
                access_token,
                openid,
                lang
            };
            const resp = yield this.oa.http.get(url, { params });
            if (resp.data.errcode) {
                throw new Error(`通过 access_token 换取 userinfo 失败: ${JSON.stringify(resp.data)}`);
            }
            return resp.data;
        });
    }
}
exports.MPOAuth = MPOAuth;
